summaryrefslogtreecommitdiffstats
path: root/src/uri_auth.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/uri_auth.c')
-rw-r--r--src/uri_auth.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/uri_auth.c b/src/uri_auth.c
index db7e6c6..979b327 100644
--- a/src/uri_auth.c
+++ b/src/uri_auth.c
@@ -110,7 +110,7 @@ struct uri_auth *stats_set_realm(struct uri_auth **root, char *realm)
}
/*
* Returns a default uri_auth with STAT_SHNODE flag enabled and
* <node> set as the name if it is not empty.
* Uses the pointer provided if not NULL and not initialized.
*/
@@ -128,7 +128,7 @@ struct uri_auth *stats_set_node(struct uri_auth **root, char *name)
if ((u = stats_check_init_uri_auth(root)) == NULL)
goto out_u;
- if (!stats_set_flag(root, STAT_SHNODE))
+ if (!stats_set_flag(root, STAT_F_SHNODE))
goto out_u;
if (node_copy) {
@@ -145,7 +145,7 @@ struct uri_auth *stats_set_node(struct uri_auth **root, char *name)
}
/*
* Returns a default uri_auth with STAT_SHDESC flag enabled and
* <description> set as the desc if it is not empty.
* Uses the pointer provided if not NULL and not initialized.
*/
@@ -163,7 +163,7 @@ struct uri_auth *stats_set_desc(struct uri_auth **root, char *desc)
if ((u = stats_check_init_uri_auth(root)) == NULL)
goto out_u;
- if (!stats_set_flag(root, STAT_SHDESC))
+ if (!stats_set_flag(root, STAT_F_SHDESC))
goto out_u;
if (desc_copy) {
@@ -110,7 +110,7 @@ struct uri_auth *stats_set_realm(struct uri_auth **root, char *realm)
}
/*
- * Returns a default uri_auth with STAT_SHNODE flag enabled and
+ * Returns a default uri_auth with STAT_F_SHNODE flag enabled and
* <node> set as the name if it is not empty.
* Uses the pointer provided if not NULL and not initialized.
@@ -145,7 +145,7 @@ struct uri_auth *stats_set_node(struct uri_auth **root, char *name)
}
/*
- * Returns a default uri_auth with STAT_SHDESC flag enabled and
+ * Returns a default uri_auth with STAT_F_SHDESC flag enabled and
* <description> set as the desc if it is not empty.
* Uses the pointer provided if not NULL and not initialized.